@@ -365,6 +365,7 @@ _svmf_bootstrap (_svmt_JNIEnv *env)
      m4svm_create_link_and_initialize_class(java/lang/reflect/Field, jlrfield)
      m4svm_create_link_and_initialize_class(java/lang/reflect/InvocationTargetException, jlrinvocationtargetexception)
      m4svm_create_link_and_initialize_class(java/lang/reflect/Method, jlrmethod)
+     m4svm_create_link_and_initialize_class(java/nio/ByteBuffer$vm, niobytebuffervm)
 
      m4svm_create_and_link_array([Ljava/lang/reflect/Field;, jlrfield_array)
 
@@ -427,6 +428,8 @@ _svmf_bootstrap (_svmt_JNIEnv *env)
      m4svm_find_method(createString, ([B)Ljava/lang/String;, stringcreator, createstring)
      m4svm_find_method(createStringFromChars, ([C)Ljava/lang/String;, stringcreator, createstringfromchars)
      m4svm_find_method(exceptionDescribe, (Ljava/lang/Throwable;)V, virtualmachine, exceptiondescribe)
+     m4svm_find_method(exceptionDescription, (Ljava/lang/Throwable;)Ljava/lang/String;, virtualmachine, exceptiondescription)
+     m4svm_find_method(exceptionTruncatedDescription, (Ljava/lang/Throwable;)Ljava/lang/String;, virtualmachine, exceptiontruncateddescription)
      m4svm_find_method(getChars, (Ljava/lang/String;)[C, stringcreator, getchars)
      m4svm_find_method(getLength, (Ljava/lang/String;)I, stringcreator, getlength)
      m4svm_find_method(getSystemClassLoader, ()[B, virtualmachine, getsystemcl)
@@ -434,6 +437,25 @@ _svmf_bootstrap (_svmt_JNIEnv *env)
      m4svm_find_method(getUTFLength, (Ljava/lang/String;)I, stringcreator, getutflength)
      m4svm_find_method(initialize, (I)V, jlclass, initialize)
      m4svm_find_method(runThread, ()V, virtualmachine, runthread)
+     m4svm_find_method(vmGetDirectBufferCapacity, (Ljava/nio/ByteBuffer;)J, niobytebuffervm, getcapacity)
+
+     m4svm_on(0)
+     #if SVM_WORD_BIT_COUNT == 32
+     m4svm_off()
+
+     m4svm_find_method(vmGetDirectBufferAddress32, (Ljava/nio/ByteBuffer;)I, niobytebuffervm, getaddress32)
+     m4svm_find_method(vmNewDirectByteBuffer32, (IJ)Ljava/nio/ByteBuffer;, niobytebuffervm, newbuffer32)
+
+     m4svm_on(0)
+     #elif SVM_WORD_BIT_COUNT == 64
+     m4svm_off()
+
+     m4svm_find_method(vmGetDirectBufferAddress64, (Ljava/nio/ByteBuffer;)J, niobytebuffervm, getaddress64)
+     m4svm_find_method(vmNewDirectByteBuffer64, (JJ)Ljava/nio/ByteBuffer;, niobytebuffervm, newbuffer64)
+
+     m4svm_on(0)
+     #endif
+     m4svm_off()
 
      m4svm_find_method(<init>, (Ljava/lang/String;)V, ArithmeticException, init)
      m4svm_find_method(<init>, (Ljava/lang/String;)V, ArrayIndexOutOfBoundsException, init)
@@ -474,6 +496,9 @@ _svmf_bootstrap (_svmt_JNIEnv *env)
      m4svm_off()
 
      m4svm_find_field(vmdata, Ljava/lang/Object;, jlclass, vmdata)
+     m4svm_find_field(vmData, [B, jlrfield, vmdata)
+     m4svm_find_field(vmData, [B, jlrmethod, vmdata)
+     m4svm_find_field(vmData, [B, jlrconstructor, vmdata)
      m4svm_find_field(next, Ljava/lang/StackTraceElement;, jlstacktraceelement, next)
      m4svm_find_field(length, I, jlstacktraceelement, length)
 
