@@ -177,6 +177,30 @@ m4_dnl ()
   m4svm_define_end = ":])";
 }
 
+/*
+----------------------------------------------------------------------
+m4svm_parse_attribute_elseifexternal
+----------------------------------------------------------------------
+*/
+
+/* usage: specify the attribute name as the first parameter and the
+   package name as the second parameter.
+*/
+
+void
+m4_dnl ()
+{
+  if (dummy)
+    m4svm_define_begin = ":], [:m4svm_parse_attribute_elseifexternal:])";
+  else if (strcmp (name, "$2.$1") == 0)
+    {
+      /* m4svm_comment_define([:m4svm_parse_attribute_1:],
+       * [:[:m4svm_parse_attribute($:][:1):][::]m4_dnl:]) */
+      m4svm_parse_attribute_1 = dummy;
+
+    }
+  m4svm_define_end = ":])";
+}
 
 /*
 ----------------------------------------------------------------------
