@@ -159,6 +159,16 @@
 #define SVM_THREAD_STATUS_NOT_RUNNING_JAVA_RESUMING_ALLOWED 3
 #define SVM_THREAD_STATUS_NOT_RUNNING_JAVA_RESUMING_DISALLOWED 4
 
+/* thread status flags */
+#define SVM_THREAD_STATUS_FLAGS_NONE 0x00000000
+#define SVM_THREAD_STATUS_FLAGS_STOP_THE_WORLD 0x00000001
+#define SVM_THREAD_STATUS_FLAGS_SUSPEND 0x00000002
+
+/* size of trace history on stop/resume java calls */
+#ifndef NDEBUG
+#define SVM_STOP_RESUME_TRACE_SIZE 100
+#endif
+
 /* maximum size of a string to keep instruction name */
 #define _SABLEVM_BYTECODE_NAME_MAX_LENGTH 30
 
