@@ -30,6 +30,7 @@ extern "C"
 
 #define JNI_VERSION_1_1 0x00010001
 #define JNI_VERSION_1_2 0x00010002
+#define JNI_VERSION_1_4 0x00010004
 
 #define JNI_OK 0
 #define JNI_ERR (-1)
@@ -584,6 +585,9 @@ struct JNINativeInterface_struct
   jweak (JNICALL *NewWeakGlobalRef) (JNIEnv *env, jobject obj);	/* 226 */
   void (JNICALL *DeleteWeakGlobalRef) (JNIEnv *env, jweak wref);	/* 227 */
   jboolean (JNICALL *ExceptionCheck) (JNIEnv *env);	/* 228 */
+  jobject (JNICALL *NewDirectByteBuffer) (JNIEnv* env, void* address, jlong capacity); /* 229 */
+  void* (JNICALL *GetDirectBufferAddress) (JNIEnv* env, jobject buf); /* 230 */
+  jlong (JNICALL *GetDirectBufferCapacity) (JNIEnv* env, jobject buf); /* 231 */
 };
 /* *INDENT-ON* */
 
