@@ -21,11 +21,11 @@ void
 _svmf_verbose_instructions_inlined (_svmt_JNIEnv *env,
 				    _svmt_code *pc, char *name)
 {
-  if (env->vm->verbose_instructions)
+  if (env->vm->verbose_instructions == JNI_TRUE)
     {
       _svmf_printf (env, stderr,
-		    "[verbose instructions: executing @%p %s]\n",
-		    (void *) (pc - 1), name);
+		    "T%d: [verbose instructions: executing @%p %s]\n",
+		    env->thread.id, (void *) (pc - 1), name);
       fflush (NULL);
     }
 }
@@ -502,7 +502,8 @@ exception_handler:
       }
 
     /* structured locking */
-    if (env->stack.current_frame->lock_count != 0)
+    if (env->stack.current_frame->lock_count != 0
+	&& env->vm->enforce_structured_locking)
       {
 	/* pop stack frame */
 	frame = env->stack.current_frame;
