@@ -11,7 +11,7 @@ static pthread_mutex_t _svmv_vm_list_mutex = PTHREAD_MUTEX_INITIALIZER;	/* prote
 static _svmt_JavaVM *_svmv_vm_list = NULL;	/* list of vms */
 
 /* interface table */
-static JNIInvokeInterface _svmv_invoke_interface = {
+static const JNIInvokeInterface _svmv_invoke_interface = {
   NULL,
   NULL,
   NULL,
@@ -37,8 +37,10 @@ JNI_GetDefaultJavaVMInitArgs (void *_vm_args)
       goto error;
     }
 
-  /* we only communicate using the 1.2 interface version */
-  if (vm_args->version != JNI_VERSION_1_2)
+  /* we only communicate using the 1.2 and 1.4 interface versions */
+  if (!
+      (vm_args->version == JNI_VERSION_1_2
+       || vm_args->version == JNI_VERSION_1_4))
     {
       goto error;
     }
@@ -109,8 +111,10 @@ JNI_CreateJavaVM (JavaVM **pvm, void **penv, void *_vm_args)
       goto error;
     }
 
-  /* we only communicate using the 1.2 interface version */
-  if (vm_args->version != JNI_VERSION_1_2)
+  /* we only communicate using the 1.2 and 1.4 interface versions */
+  if (!
+      (vm_args->version == JNI_VERSION_1_2
+       || vm_args->version == JNI_VERSION_1_4))
     {
       goto error;
     }
@@ -130,8 +134,7 @@ JNI_CreateJavaVM (JavaVM **pvm, void **penv, void *_vm_args)
 
   vm->interface = &_svmv_invoke_interface;
   _svmm_mutex_init (vm->global_mutex);
-  _svmm_cond_init (vm->requesting_thread_cond);
-  _svmm_cond_init (vm->halted_threads_cond);
+  _svmm_cond_init (vm->stop_the_world.requesting_thread_cond);
   vm->vfprintf = vfprintf;
   vm->exit = exit;
   vm->abort = abort;
@@ -236,6 +239,8 @@ JNI_CreateJavaVM (JavaVM **pvm, void **penv, void *_vm_args)
   env->thread_status = SVM_THREAD_STATUS_RUNNING_JAVA;
   env->is_alive = JNI_TRUE;
 
+  _svmm_cond_init (env->wakeup_cond);
+  _svmm_cond_init (env->suspension.cond);
   _svmm_mutex_init (env->contention.owner.mutex);
   _svmm_cond_init (env->contention.requester.cond);
 
@@ -388,7 +393,7 @@ JNI_CreateJavaVM (JavaVM **pvm, void **penv, void *_vm_args)
   _svmf_inlined_testing_initialize (env);
 #endif
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return JNI_OK;
 
@@ -414,7 +419,7 @@ DestroyJavaVM (JavaVM *_vm)
       return JNI_ERR;
     }
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   _svmm_mutex_lock (vm->global_mutex);
 
@@ -536,13 +541,14 @@ GetEnv (JavaVM *vm, void **penv, jint interface_id)
 
   switch (interface_id)
     {
+    case JNI_VERSION_1_4:
     case JNI_VERSION_1_2:
     case JNI_VERSION_1_1:
       break;
     default:
       _svmf_printf (env, stderr,
 		    "*** Warning: JNI version requested in GetEnv() is unavailable.\n"
-		    "***          Only JNI 1.2 and 1.1 are supported here.");
+		    "***          Only JNI 1.4, 1.2, and 1.1 are supported here.");
       (*penv) = NULL;
       return JNI_EVERSION;
     }
