@@ -24,14 +24,14 @@ Java_java_lang_Object_getClass (JNIEnv *_env, jobject this)
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jclass class;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     class = _svmf_get_jni_frame_native_local (env);
     *class = *((*this)->vtable->type->class_instance);
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return class;
 }
