@@ -24,7 +24,7 @@ Java_java_lang_Throwable_nativeGetStackTraceList (JNIEnv *_env, jobject this)
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jobject result = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_JavaVM *vm = env->vm;
@@ -270,7 +270,7 @@ end:
   _svmf_printf (env, stderr, "--\n");
 #endif
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return result;
 }
