@@ -37,7 +37,7 @@ Java_java_lang_VMClass_isInstance (JNIEnv *_env, jclass vmclass SVM_UNUSED,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jboolean result;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_type_info *T = _svmf_unwrap_class_instance (env, theclass);
@@ -46,7 +46,7 @@ Java_java_lang_VMClass_isInstance (JNIEnv *_env, jclass vmclass SVM_UNUSED,
     result = _svmf_is_assignable_from (env, S, T);
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return result;
 }
@@ -70,7 +70,7 @@ Java_java_lang_VMClass_getModifiers (JNIEnv *_env, jclass vmclass SVM_UNUSED,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jint result;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_type_info *type = _svmf_unwrap_class_instance (env, theclass);
@@ -81,7 +81,7 @@ Java_java_lang_VMClass_getModifiers (JNIEnv *_env, jclass vmclass SVM_UNUSED,
        SVM_ACC_FINAL | SVM_ACC_SUPER | SVM_ACC_INTERFACE | SVM_ACC_ABSTRACT);
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return result;
 }
@@ -107,7 +107,7 @@ Java_java_lang_VMClass_getDeclaringClass (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jclass class = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_type_info *type = _svmf_unwrap_class_instance (env, theclass);
@@ -175,7 +175,7 @@ Java_java_lang_VMClass_getDeclaringClass (JNIEnv *_env,
   }
 end:
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return class;
 }
@@ -202,7 +202,7 @@ Java_java_lang_VMClass_getDeclaredClasses (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jobjectArray classes = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_JavaVM *vm = env->vm;
@@ -359,7 +359,7 @@ Java_java_lang_VMClass_getDeclaredClasses (JNIEnv *_env,
   }
 end:
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return classes;
 }
@@ -385,7 +385,7 @@ Java_java_lang_VMClass_isInterface (JNIEnv *_env, jclass vmclass SVM_UNUSED,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jboolean result;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_type_info *type = _svmf_unwrap_class_instance (env, theclass);
@@ -401,7 +401,7 @@ Java_java_lang_VMClass_isInterface (JNIEnv *_env, jclass vmclass SVM_UNUSED,
       }
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return result;
 }
@@ -426,7 +426,7 @@ Java_java_lang_VMClass_getSuperclass (JNIEnv *_env, jclass vmclass SVM_UNUSED,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jclass super = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_JavaVM *vm = env->vm;
@@ -462,7 +462,7 @@ Java_java_lang_VMClass_getSuperclass (JNIEnv *_env, jclass vmclass SVM_UNUSED,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return super;
 }
@@ -488,7 +488,7 @@ Java_java_lang_VMClass_getInterfaces (JNIEnv *_env, jclass vmclass SVM_UNUSED,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jobjectArray interfaces_array = NULL;	/* The result. */
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_JavaVM *vm = env->vm;
@@ -571,7 +571,7 @@ Java_java_lang_VMClass_getInterfaces (JNIEnv *_env, jclass vmclass SVM_UNUSED,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return interfaces_array;
 }
@@ -602,7 +602,7 @@ Java_java_lang_VMClass_getDeclaredFields (JNIEnv *_env,
 
   /* disable concurrent garbage collection, stopping the world if
      garbage collection is in progress */
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_JavaVM *vm = env->vm;
@@ -828,7 +828,7 @@ Java_java_lang_VMClass_getDeclaredFields (JNIEnv *_env,
   /* returning to foreing JNI code.  As we don't know when this code
      will call back (or return to) the VM, we must enable concurrent
      garbage collection.  */
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return fields_array;
 }
@@ -852,7 +852,7 @@ getDeclaredMethodsConstructors_helper (_svmt_JNIEnv *env, jclass theclass,
 {
   jobjectArray methods_array = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_JavaVM *vm = env->vm;
@@ -1105,7 +1105,7 @@ getDeclaredMethodsConstructors_helper (_svmt_JNIEnv *env, jclass theclass,
   }
 
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
   return methods_array;
 }
 
@@ -1179,7 +1179,7 @@ Java_java_lang_VMClass_isAssignableFrom (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jboolean is_assignable;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_type_info *to = _svmf_unwrap_class_instance (env, theclass);
@@ -1188,7 +1188,7 @@ Java_java_lang_VMClass_isAssignableFrom (JNIEnv *_env,
     is_assignable = _svmf_is_assignable_from (env, from, to);
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return is_assignable;
 }
@@ -1213,7 +1213,7 @@ Java_java_lang_VMClass_getClassLoader (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jobject class_loader = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_type_info *type = _svmf_unwrap_class_instance (env, theclass);
@@ -1225,7 +1225,7 @@ Java_java_lang_VMClass_getClassLoader (JNIEnv *_env,
       }
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return class_loader;
 }
@@ -1250,7 +1250,7 @@ Java_java_lang_VMClass_getName (JNIEnv *_env, jclass vmclass SVM_UNUSED,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jstring name;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_class_info *class =
@@ -1260,7 +1260,7 @@ Java_java_lang_VMClass_getName (JNIEnv *_env, jclass vmclass SVM_UNUSED,
     _svmf_get_string (env, class->name, name);
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return name;
 }
@@ -1284,7 +1284,7 @@ Java_java_lang_VMClass_isInitialized (JNIEnv *_env, jclass vmclass SVM_UNUSED,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jboolean result;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_class_info *class =
@@ -1295,7 +1295,7 @@ Java_java_lang_VMClass_isInitialized (JNIEnv *_env, jclass vmclass SVM_UNUSED,
 			 SVM_TYPE_STATE_INITIALIZED) ? JNI_TRUE : JNI_FALSE;
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return result;
 }
@@ -1319,7 +1319,7 @@ Java_java_lang_VMClass_setInitialized (JNIEnv *_env,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_class_info *class =
@@ -1328,7 +1328,7 @@ Java_java_lang_VMClass_setInitialized (JNIEnv *_env,
     _svmm_set_flag (class->state, SVM_TYPE_STATE_INITIALIZED);
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 }
 
 /*
@@ -1349,7 +1349,7 @@ Java_java_lang_VMClass_step7 (JNIEnv *_env, jclass vmclass SVM_UNUSED,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_class_info *class =
@@ -1372,7 +1372,7 @@ Java_java_lang_VMClass_step7 (JNIEnv *_env, jclass vmclass SVM_UNUSED,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 }
 
 /*
@@ -1393,7 +1393,7 @@ Java_java_lang_VMClass_step8 (JNIEnv *_env, jclass vmclass SVM_UNUSED,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_class_info *class =
@@ -1419,7 +1419,7 @@ Java_java_lang_VMClass_step8 (JNIEnv *_env, jclass vmclass SVM_UNUSED,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 }
 
 
@@ -1429,11 +1429,11 @@ Java_java_lang_VMClass_throwException (JNIEnv *_env, jclass _class SVM_UNUSED,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     *(env->throwable) = *exception;
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 }
