@@ -27,7 +27,7 @@ Java_java_lang_VMClassLoader_nativeGetResource (JNIEnv *_env,
   jstring result = NULL;
   char *res_url, *name;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     if (_svmm_galloc_utf_chars (env, _name, name) != JNI_OK)
@@ -48,7 +48,7 @@ Java_java_lang_VMClassLoader_nativeGetResource (JNIEnv *_env,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return result;
 }
@@ -73,7 +73,7 @@ Java_java_lang_VMClassLoader_newClassLoaderVmData (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jbyteArray vmData = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_JavaVM *vm = env->vm;
@@ -126,7 +126,7 @@ Java_java_lang_VMClassLoader_newClassLoaderVmData (JNIEnv *_env,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return vmData;
 }
@@ -151,7 +151,7 @@ Java_java_lang_VMClassLoader_getPrimitiveArray (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jclass array_instance = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_JavaVM *vm = env->vm;
@@ -259,7 +259,7 @@ Java_java_lang_VMClassLoader_getPrimitiveArray (JNIEnv *_env,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return array_instance;
 }
@@ -283,7 +283,7 @@ Java_java_lang_VMClassLoader_getArray (JNIEnv *_env, jclass _class SVM_UNUSED,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jclass array_instance = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
 #ifndef NDEBUG
@@ -308,7 +308,7 @@ Java_java_lang_VMClassLoader_getArray (JNIEnv *_env, jclass _class SVM_UNUSED,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return array_instance;
 }
@@ -334,7 +334,7 @@ Java_java_lang_VMClassLoader_nativeDefineArray (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jclass array_instance = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_class_loader_info *class_loader_info = _svmf_unwrap_pointer (*cl);
@@ -436,7 +436,7 @@ Java_java_lang_VMClassLoader_nativeDefineArray (JNIEnv *_env,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return array_instance;
 }
@@ -464,7 +464,7 @@ Java_java_lang_VMClassLoader_nativeDefineClass (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jclass class_instance = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_class_loader_info *class_loader_info = _svmf_unwrap_pointer (*cl);
@@ -539,7 +539,7 @@ Java_java_lang_VMClassLoader_nativeDefineClass (JNIEnv *_env,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return class_instance;
 }
@@ -563,7 +563,7 @@ Java_java_lang_VMClassLoader_linkClass (JNIEnv *_env,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_type_info *type = _svmf_unwrap_class_instance (env, class);
@@ -575,7 +575,7 @@ Java_java_lang_VMClassLoader_linkClass (JNIEnv *_env,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 }
 
 /*
@@ -597,7 +597,7 @@ Java_java_lang_VMClassLoader_initializeClass (JNIEnv *_env,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_type_info *type = _svmf_unwrap_class_instance (env, class);
@@ -619,7 +619,7 @@ Java_java_lang_VMClassLoader_initializeClass (JNIEnv *_env,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 }
 
 /*
@@ -643,7 +643,7 @@ Java_java_lang_VMClassLoader_nativeLoadClass (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jclass class = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_JavaVM *vm = env->vm;
@@ -687,7 +687,7 @@ Java_java_lang_VMClassLoader_nativeLoadClass (JNIEnv *_env,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return class;
 }
@@ -713,7 +713,7 @@ Java_java_lang_VMClassLoader_nativeCreateArray (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jclass class = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_JavaVM *vm = env->vm;
@@ -753,7 +753,7 @@ Java_java_lang_VMClassLoader_nativeCreateArray (JNIEnv *_env,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return class;
 }
@@ -778,7 +778,7 @@ Java_java_lang_VMClassLoader_getPrimitiveClass (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jclass type = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_JavaVM *vm = env->vm;
@@ -851,7 +851,7 @@ Java_java_lang_VMClassLoader_getPrimitiveClass (JNIEnv *_env,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return type;
 }
