@@ -24,7 +24,7 @@ Java_java_lang_VMObject_notify (JNIEnv *_env, jclass class SVM_UNUSED,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   _svmt_JavaVM *vm = env->vm;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_object_instance *instance = *o;
@@ -64,7 +64,7 @@ Java_java_lang_VMObject_notify (JNIEnv *_env, jclass class SVM_UNUSED,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 }
 
 /*
@@ -85,7 +85,7 @@ Java_java_lang_VMObject_notifyAll (JNIEnv *_env, jclass class SVM_UNUSED,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   _svmt_JavaVM *vm = env->vm;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_object_instance *instance = *o;
@@ -125,7 +125,7 @@ Java_java_lang_VMObject_notifyAll (JNIEnv *_env, jclass class SVM_UNUSED,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 }
 
 /*
@@ -147,7 +147,7 @@ Java_java_lang_VMObject_wait (JNIEnv *_env, jclass class SVM_UNUSED,
   _svmt_JavaVM *vm = env->vm;
   int throw_interrupted_requested = JNI_FALSE;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_object_instance *instance = *o;
@@ -231,7 +231,7 @@ Java_java_lang_VMObject_wait (JNIEnv *_env, jclass class SVM_UNUSED,
 	}
 
       /* prepare to sleep... */
-      _svmf_stopping_java (env);
+      _svmm_stopping_java (env);
 
       _svmm_mutex_lock (fat_lock->mutex);
 
@@ -296,60 +296,37 @@ Java_java_lang_VMObject_wait (JNIEnv *_env, jclass class SVM_UNUSED,
 
 	    /* I don't care about overflow of timeout.tv_sec. */
 
-	    for (;;)
+	    /* Don't count on returned value. According to the OpenGroup specs
+	       it should _never_ return EINTR ! Check interrupted_status flag */
+
+	    _svmm_cond_timedwait (fat_lock->notification_cond,
+				  fat_lock->mutex, timeout);
+
+	    /* have we been interrupted ? */
+	    do
 	      {
-		struct timeval tvnow;
-		struct timespec tsnow;
-
-		/* Don't count on returned value. According to the OpenGroup specs
-		   it should _never_ return EINTR ! Check interrupted_status flag
-		   and timeout instead */
-
-		_svmm_cond_timedwait (fat_lock->notification_cond,
-				      fat_lock->mutex, timeout);
-
-		/* are we sure we should wake up? have we been interrupted or the time passed? */
-
-		do
-		  {
-		    old_interrupted_status = env->thread.interrupted_status;
-		    new_interrupted_status = old_interrupted_status;
-
-		    if (old_interrupted_status & SVM_THREAD_THROW_INTERRUPTED)
-		      {
-			new_interrupted_status &=
-			  ~SVM_THREAD_INTERRUPTIBLE_ON_FAT_LOCK;
-			new_interrupted_status &=
-			  ~SVM_THREAD_THROW_INTERRUPTED;
-		      }
-		    else
-		      {
-			break;
-		      }
-		  }
-		while (!_svmm_compare_and_swap
-		       (env->thread.interrupted_status,
-			old_interrupted_status, new_interrupted_status));
+		old_interrupted_status = env->thread.interrupted_status;
+		new_interrupted_status = old_interrupted_status;
 
 		if (old_interrupted_status & SVM_THREAD_THROW_INTERRUPTED)
 		  {
-		    throw_interrupted_requested = JNI_TRUE;
-		    break;
+		    new_interrupted_status &=
+		      ~SVM_THREAD_INTERRUPTIBLE_ON_FAT_LOCK;
+		    new_interrupted_status &= ~SVM_THREAD_THROW_INTERRUPTED;
 		  }
-
-		gettimeofday (&tvnow, NULL);
-
-		tsnow.tv_sec = tvnow.tv_sec;
-		tsnow.tv_nsec = tvnow.tv_usec * 1000;
-
-		if (tsnow.tv_sec > timeout.tv_sec ||
-		    ((tsnow.tv_sec == timeout.tv_sec)
-		     && (tsnow.tv_nsec >= timeout.tv_nsec)))
+		else
 		  {
-		    /* the time is up */
 		    break;
 		  }
 	      }
+	    while (!_svmm_compare_and_swap
+		   (env->thread.interrupted_status,
+		    old_interrupted_status, new_interrupted_status));
+
+	    if (old_interrupted_status & SVM_THREAD_THROW_INTERRUPTED)
+	      {
+		throw_interrupted_requested = JNI_TRUE;
+	      }
 	  }
 
 	/* wait until no other thread owns the lock */
@@ -366,7 +343,7 @@ Java_java_lang_VMObject_wait (JNIEnv *_env, jclass class SVM_UNUSED,
 
       _svmm_mutex_unlock ();
 
-      _svmf_resuming_java (env);
+      _svmm_resuming_java (env);
 
       /* throw an InterruptedException if we've been interrupt()ed */
       if (throw_interrupted_requested == JNI_TRUE)
@@ -378,7 +355,7 @@ Java_java_lang_VMObject_wait (JNIEnv *_env, jclass class SVM_UNUSED,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 }
 
 /*
@@ -400,14 +377,14 @@ Java_java_lang_VMObject_clone (JNIEnv *_env, jclass class SVM_UNUSED,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jobject clone = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     clone = _svmf_get_jni_frame_native_local (env);
     _svmf_clone_instance (env, obj, clone);
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return clone;
 }
