@@ -44,8 +44,23 @@ JNIEXPORT static jlong JNICALL
 Java_java_lang_VMRuntime_freeMemory (JNIEnv *_env SVM_UNUSED,
 				     jclass class SVM_UNUSED)
 {
-  /* to do */
-  return 0;
+  _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
+  _svmt_JavaVM *vm = env->vm;
+  jlong result = -1;
+
+  _svmm_resuming_java (env);
+
+#if defined (_SABLEVM_COPY_GC)
+  {
+    size_t heap_free = ((char *) vm->heap.end) - ((char *) vm->heap.alloc);
+
+    result = (jlong) heap_free;
+  }
+#endif
+
+  _svmm_stopping_java (env);
+
+  return result;
 }
 
 /*
@@ -64,8 +79,23 @@ JNIEXPORT static jlong JNICALL
 Java_java_lang_VMRuntime_totalMemory (JNIEnv *_env SVM_UNUSED,
 				      jclass class SVM_UNUSED)
 {
-  /* to do */
-  return 0;
+  _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
+  _svmt_JavaVM *vm = env->vm;
+  jlong result = -1;
+
+  _svmm_resuming_java (env);
+
+#if defined (_SABLEVM_COPY_GC)
+  {
+    size_t heap_total = ((char *) vm->heap.end) - ((char *) vm->heap.start);
+
+    result = (jlong) heap_total;
+  }
+#endif
+
+  _svmm_stopping_java (env);
+
+  return result;
 }
 
 /*
@@ -84,8 +114,24 @@ JNIEXPORT static jlong JNICALL
 Java_java_lang_VMRuntime_maxMemory (JNIEnv *_env SVM_UNUSED,
 				    jclass class SVM_UNUSED)
 {
-  /* to do */
-  return 0;
+  _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
+  _svmt_JavaVM *vm = env->vm;
+  jlong result = -1;
+
+  _svmm_resuming_java (env);
+
+#if defined (_SABLEVM_COPY_GC)
+  {
+    if (vm->heap.max_size == 0)
+      result = SVM_JLONG_MAX;
+    else
+      result = (jlong) vm->heap.max_size;
+  }
+#endif
+
+  _svmm_stopping_java (env);
+
+  return result;
 }
 
 /*
@@ -105,7 +151,7 @@ Java_java_lang_VMRuntime_gc (JNIEnv *_env, jclass class SVM_UNUSED)
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
 #ifdef _SABLEVM_NO_GC
 
@@ -155,7 +201,7 @@ Java_java_lang_VMRuntime_gc (JNIEnv *_env, jclass class SVM_UNUSED)
 #error todo
 #endif
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 }
 
 /*
@@ -176,11 +222,11 @@ Java_java_lang_VMRuntime_runFinalization (JNIEnv *_env,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   /* todo */
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 }
 
 /*
@@ -201,11 +247,11 @@ Java_java_lang_VMRuntime_runFinalizationForExit (JNIEnv *_env,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   /* todo */
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 }
 
 /*
@@ -227,7 +273,7 @@ Java_java_lang_VMRuntime_traceInstructions (JNIEnv *_env,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
 #if !defined(NDEBUG)
 
@@ -235,7 +281,7 @@ Java_java_lang_VMRuntime_traceInstructions (JNIEnv *_env,
 
 #endif
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 }
 
 /*
@@ -257,7 +303,7 @@ Java_java_lang_VMRuntime_traceMethodCalls (JNIEnv *_env,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
 #if !defined(NDEBUG)
 
@@ -265,7 +311,7 @@ Java_java_lang_VMRuntime_traceMethodCalls (JNIEnv *_env,
 
 #endif
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 }
 
 /*
@@ -287,11 +333,11 @@ Java_java_lang_VMRuntime_runFinalizersOnExit (JNIEnv *_env,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   /* todo */
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 }
 
 /*
@@ -351,7 +397,7 @@ Java_java_lang_VMRuntime_nativeLoad (JNIEnv *_env, jclass class SVM_UNUSED,
   _svmt_JavaVM *vm = env->vm;
   const char *errmsg = "unknown error";
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     char *filename;
@@ -407,8 +453,9 @@ Java_java_lang_VMRuntime_nativeLoad (JNIEnv *_env, jclass class SVM_UNUSED,
 	{
 	  jint version = JNI_OnLoad (_svmf_cast_JavaVM (vm), NULL);
 
-	  if (version != JNI_VERSION_1_2)
+	  if (!(version == JNI_VERSION_1_2 || version == JNI_VERSION_1_4))
 	    {
+	      _svmm_gfree_utf_chars (filename);
 	      lt_dlclose (handle);
 	      goto end;
 	    }
@@ -446,7 +493,7 @@ Java_java_lang_VMRuntime_nativeLoad (JNIEnv *_env, jclass class SVM_UNUSED,
 
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return errmsg == NULL ? 1 : 0;
 }
@@ -470,7 +517,7 @@ Java_java_lang_VMRuntime_mapLibraryName (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jstring string = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     /*
@@ -511,7 +558,7 @@ Java_java_lang_VMRuntime_mapLibraryName (JNIEnv *_env,
 
 end:
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return string;
 }
