@@ -26,11 +26,11 @@ Java_java_lang_VMSystem_identityHashCode (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jint hashcode = 0;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   _svmm_identity_hashcode (env, obj, hashcode);
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return hashcode;
 }
@@ -54,7 +54,7 @@ Java_java_lang_VMSystem_arraycopy (JNIEnv *_env, jclass class SVM_UNUSED,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   if (dst == NULL)
     {
@@ -375,5 +375,5 @@ Java_java_lang_VMSystem_arraycopy (JNIEnv *_env, jclass class SVM_UNUSED,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 }
