@@ -36,7 +36,7 @@ Java_java_lang_reflect_Field_nativeGetDeclaringClass (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jclass dclass;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_field_info *field = _svmf_unwrap_pointer (*vmData);
@@ -45,7 +45,7 @@ Java_java_lang_reflect_Field_nativeGetDeclaringClass (JNIEnv *_env,
     *dclass = *(field->class_info->class_instance);
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return dclass;
 }
@@ -70,7 +70,7 @@ Java_java_lang_reflect_Field_nativeGetModifiers (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jint modifiers;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_field_info *field = _svmf_unwrap_pointer (*vmData);
@@ -83,7 +83,7 @@ Java_java_lang_reflect_Field_nativeGetModifiers (JNIEnv *_env,
        SVM_ACC_STATIC | SVM_ACC_FINAL | SVM_ACC_TRANSIENT | SVM_ACC_VOLATILE);
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return modifiers;
 
@@ -110,7 +110,7 @@ Java_java_lang_reflect_Field_nativeGetType (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jclass class = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_JavaVM *vm = env->vm;
@@ -239,7 +239,7 @@ Java_java_lang_reflect_Field_nativeGetType (JNIEnv *_env,
   }
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return class;
 
@@ -267,7 +267,7 @@ Java_java_lang_reflect_Field_nativeGetName (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jstring name;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_field_info *field = _svmf_unwrap_pointer (*vmData);
@@ -276,7 +276,7 @@ Java_java_lang_reflect_Field_nativeGetName (JNIEnv *_env,
     _svmf_get_string (env, DREF (field->name, value), name);
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return name;
 }
@@ -302,7 +302,7 @@ Java_java_lang_reflect_Field_nativeGetReference (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jobject value = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_field_info *field = _svmf_unwrap_pointer (*vmData);
@@ -323,7 +323,7 @@ Java_java_lang_reflect_Field_nativeGetReference (JNIEnv *_env,
       }
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return value;
 }
@@ -351,7 +351,7 @@ Java_java_lang_reflect_Field_nativeGetBoolean (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jboolean value;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_field_info *field = _svmf_unwrap_pointer (*vmData);
@@ -371,7 +371,7 @@ Java_java_lang_reflect_Field_nativeGetBoolean (JNIEnv *_env,
       }
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return value;
 }
@@ -397,7 +397,7 @@ Java_java_lang_reflect_Field_nativeGetByte (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jbyte value;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_field_info *field = _svmf_unwrap_pointer (*vmData);
@@ -417,7 +417,7 @@ Java_java_lang_reflect_Field_nativeGetByte (JNIEnv *_env,
       }
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return value;
 }
@@ -444,7 +444,7 @@ Java_java_lang_reflect_Field_nativeGetChar (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jchar value;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_field_info *field = _svmf_unwrap_pointer (*vmData);
@@ -464,7 +464,7 @@ Java_java_lang_reflect_Field_nativeGetChar (JNIEnv *_env,
       }
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return value;
 }
@@ -490,7 +490,7 @@ Java_java_lang_reflect_Field_nativeGetShort (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jshort value;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_field_info *field = _svmf_unwrap_pointer (*vmData);
@@ -526,7 +526,7 @@ Java_java_lang_reflect_Field_nativeGetShort (JNIEnv *_env,
       }
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return value;
 }
@@ -552,7 +552,7 @@ Java_java_lang_reflect_Field_nativeGetInt (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jint value = 0;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_field_info *field = _svmf_unwrap_pointer (*vmData);
@@ -607,7 +607,7 @@ Java_java_lang_reflect_Field_nativeGetInt (JNIEnv *_env,
       }
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return value;
 }
@@ -634,7 +634,7 @@ Java_java_lang_reflect_Field_nativeGetLong (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jlong value = 0;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_field_info *field = _svmf_unwrap_pointer (*vmData);
@@ -696,7 +696,7 @@ Java_java_lang_reflect_Field_nativeGetLong (JNIEnv *_env,
       }
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return value;
 }
@@ -723,7 +723,7 @@ Java_java_lang_reflect_Field_nativeGetFloat (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jfloat value = 0.0;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_field_info *field = _svmf_unwrap_pointer (*vmData);
@@ -794,7 +794,7 @@ Java_java_lang_reflect_Field_nativeGetFloat (JNIEnv *_env,
       }
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return value;
 }
@@ -822,7 +822,7 @@ Java_java_lang_reflect_Field_nativeGetDouble (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jdouble value = 0.0;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_field_info *field = _svmf_unwrap_pointer (*vmData);
@@ -899,7 +899,7 @@ Java_java_lang_reflect_Field_nativeGetDouble (JNIEnv *_env,
       }
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return value;
 }
@@ -925,7 +925,7 @@ Java_java_lang_reflect_Field_nativeSetReference (JNIEnv *_env,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_field_info *field = _svmf_unwrap_pointer (*vmData);
@@ -945,7 +945,7 @@ Java_java_lang_reflect_Field_nativeSetReference (JNIEnv *_env,
       }
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
 }
 
@@ -972,7 +972,7 @@ Java_java_lang_reflect_Field_nativeSetBoolean (JNIEnv *_env,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_field_info *field = _svmf_unwrap_pointer (*vmData);
@@ -992,7 +992,7 @@ Java_java_lang_reflect_Field_nativeSetBoolean (JNIEnv *_env,
       }
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
 }
 
@@ -1016,7 +1016,7 @@ Java_java_lang_reflect_Field_nativeSetByte (JNIEnv *_env,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_field_info *field = _svmf_unwrap_pointer (*vmData);
@@ -1080,7 +1080,7 @@ Java_java_lang_reflect_Field_nativeSetByte (JNIEnv *_env,
       }
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
 }
 
@@ -1105,7 +1105,7 @@ Java_java_lang_reflect_Field_nativeSetChar (JNIEnv *_env,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_field_info *field = _svmf_unwrap_pointer (*vmData);
@@ -1163,7 +1163,7 @@ Java_java_lang_reflect_Field_nativeSetChar (JNIEnv *_env,
       }
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
 }
 
@@ -1187,7 +1187,7 @@ Java_java_lang_reflect_Field_nativeSetShort (JNIEnv *_env,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
 
@@ -1247,7 +1247,7 @@ Java_java_lang_reflect_Field_nativeSetShort (JNIEnv *_env,
 
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
 
 }
@@ -1272,7 +1272,7 @@ Java_java_lang_reflect_Field_nativeSetInt (JNIEnv *_env,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_field_info *field = _svmf_unwrap_pointer (*vmData);
@@ -1326,7 +1326,7 @@ Java_java_lang_reflect_Field_nativeSetInt (JNIEnv *_env,
 
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
 }
 
@@ -1350,7 +1350,7 @@ Java_java_lang_reflect_Field_nativeSetLong (JNIEnv *_env,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
 
@@ -1399,7 +1399,7 @@ Java_java_lang_reflect_Field_nativeSetLong (JNIEnv *_env,
 
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
 }
 
@@ -1424,7 +1424,7 @@ Java_java_lang_reflect_Field_nativeSetFloat (JNIEnv *_env,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
 
@@ -1478,7 +1478,7 @@ Java_java_lang_reflect_Field_nativeSetFloat (JNIEnv *_env,
 
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
 }
 
@@ -1503,7 +1503,7 @@ Java_java_lang_reflect_Field_nativeSetDouble (JNIEnv *_env,
 {
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
 
@@ -1524,6 +1524,6 @@ Java_java_lang_reflect_Field_nativeSetDouble (JNIEnv *_env,
       }
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
 }
