@@ -22,7 +22,7 @@ Java_java_lang_reflect_Method_nativeGetDeclaringClass (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jclass dclass;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_method_info *method = _svmf_unwrap_pointer (*vmData);
@@ -31,7 +31,7 @@ Java_java_lang_reflect_Method_nativeGetDeclaringClass (JNIEnv *_env,
     *dclass = *(method->class_info->class_instance);
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return dclass;
 }
@@ -52,7 +52,7 @@ Java_java_lang_reflect_Method_nativeGetName (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jstring name;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_method_info *method = _svmf_unwrap_pointer (*vmData);
@@ -62,7 +62,7 @@ Java_java_lang_reflect_Method_nativeGetName (JNIEnv *_env,
     _svmf_get_string (env, (*(method->name))->value, name);
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return name;
 }
@@ -89,7 +89,7 @@ Java_java_lang_reflect_Method_nativeGetModifiers (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jint modifiers;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_method_info *method = _svmf_unwrap_pointer (*vmData);
@@ -105,7 +105,7 @@ Java_java_lang_reflect_Method_nativeGetModifiers (JNIEnv *_env,
     /* what is the modifier STRICT? */
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return modifiers;
 
@@ -127,7 +127,7 @@ Java_java_lang_reflect_Method_nativeGetExceptionTypes (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jobjectArray classes = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_JavaVM *vm = env->vm;
@@ -218,7 +218,7 @@ Java_java_lang_reflect_Method_nativeGetExceptionTypes (JNIEnv *_env,
 
 
 end:
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return classes;
 
@@ -248,7 +248,7 @@ Java_java_lang_reflect_Method_invokeNative (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jobject current_exception = NULL;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_method_info *method = _svmf_unwrap_pointer (*vmData);
@@ -656,7 +656,7 @@ end:
       _svmm_free_native_local (env, current_exception);
     }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 }
 
 
@@ -673,7 +673,7 @@ Java_java_lang_reflect_Method_nativeGetDescriptor (JNIEnv *_env,
   _svmt_JNIEnv *env = _svmf_cast_svmt_JNIEnv (_env);
   jstring descriptor;
 
-  _svmf_resuming_java (env);
+  _svmm_resuming_java (env);
 
   {
     _svmt_method_info *method = _svmf_unwrap_pointer (*vmData);
@@ -682,7 +682,7 @@ Java_java_lang_reflect_Method_nativeGetDescriptor (JNIEnv *_env,
     _svmf_get_string (env, DREF (method->descriptor, value), descriptor);
   }
 
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   return descriptor;
 }
