@@ -15,7 +15,7 @@ _svmf_internal_init
 ----------------------------------------------------------------------
 */
 
-static void
+svm_static void
 _svmf_internal_init (void)
 {
   if (lt_dlinit () != 0)
@@ -42,7 +42,7 @@ _svmf_init
 ----------------------------------------------------------------------
 */
 
-static jint
+svm_static jint
 _svmf_init (void)
 {
   /*  make sure internal_init is called only once */
