@@ -25,6 +25,7 @@
 #include <sys/mman.h>
 #include <zlib.h>
 #include <limits.h>
+#include <sys/utsname.h>
 #include "time.h"
 #include "sys/time.h"
 
@@ -54,18 +55,18 @@
 #include "interpreter.h"
 #include "method_invoke.h"
 #include "new_instance.h"
+#include "native_interface.h"
 
+#include "gnu_classpath_VMSystemProperties.h"
+#include "gnu_classpath_VMStackWalker.h"
 #include "java_io_VMObjectStreamClass.h"
 #include "java_lang_Object.h"
 #include "java_lang_VMRuntime.h"
-#include "java_lang_SecurityManager.h"
 #include "java_lang_Throwable.h"
 #include "java_lang_VMClass.h"
 #include "java_lang_VMClassLoader.h"
 #include "java_lang_VMObject.h"
-#include "java_lang_VMSecurityManager.h"
 #include "java_lang_VMSystem.h"
-#include "gnu_classpath_VMSystemProperties.h"
 #include "java_lang_VMThread.h"
 #include "java_lang_VirtualMachine.h"
 #include "java_lang_reflect_Array.h"
@@ -90,13 +91,13 @@
 #include "gc_none.c"
 #include "gc_copying.c"
 #include "gc_gencopy.c"
-#include "new_instance.c"
 #include "method_invoke.c"
 #include "util2.c"
 #include "resolve.c"
 #include "class_loader_memory_manager.c"
 #include "cl_alloc.c"
 #include "class_file_parser.c"
+#include "new_instance.c"
 #include "splay_tree.c"
 #include "zip_file_reader.h"
 #include "zip_file_reader.c"
@@ -116,18 +117,17 @@
 #include "bootstrap.c"
 #include "invoke_interface.c"
 
+#include "gnu_classpath_VMSystemProperties.c"
+#include "gnu_classpath_VMStackWalker.c"
 #include "java_io_VMObjectStreamClass.c"
 #include "java_lang_Object.c"
 #include "java_lang_VMRuntime.c"
-#include "java_lang_SecurityManager.c"
 #include "java_lang_VMThread.c"
 #include "java_lang_Throwable.c"
 #include "java_lang_VMClass.c"
 #include "java_lang_VMClassLoader.c"
 #include "java_lang_VMObject.c"
-#include "java_lang_VMSecurityManager.c"
 #include "java_lang_VMSystem.c"
-#include "gnu_classpath_VMSystemProperties.c"
 #include "java_lang_VirtualMachine.c"
 #include "java_lang_reflect_Array.c"
 #include "java_lang_reflect_Constructor.c"
