@@ -61,7 +61,7 @@ _svmh_invoke_nonvirtual_$1
  * $:][:2, jobject, [:, jobject ret:],
  * :]m4svm_lbkt[:, $:][:2 *ret:]m4svm_rbkt[:)[::]m4_dnl
  * :]:]) */
-static jint
+svm_static jint
 _svmh_invoke_nonvirtual_$1 (_svmt_JNIEnv *env, jobject m4svm_arglist)
 {
   _svmt_JavaVM *vm = env->vm;
@@ -98,7 +98,7 @@ _svmh_invoke_nonvirtual_$1 (_svmt_JNIEnv *env, jobject m4svm_arglist)
   /* setup internal call frame */
   {
     size_t offset = env->stack.current_frame->end_offset;
-    _svmt_stack_frame *frame = (_svmt_stack_frame *)
+    _svmt_stack_frame *frame = (_svmt_stack_frame *) (void *)
       (((char *) env->stack.current_frame) + offset);
 
     frame->previous_offset = offset;
@@ -116,7 +116,7 @@ _svmh_invoke_nonvirtual_$1 (_svmt_JNIEnv *env, jobject m4svm_arglist)
   /* push parameters */
   {
     _svmt_stack_frame *prev_frame = env->stack.current_frame;
-    _svmt_stack_value *locals = (_svmt_stack_value *)
+    _svmt_stack_value *locals = (_svmt_stack_value *) (void *)
       (((char *) prev_frame) + prev_frame->end_offset);
     jint i = 0;
 
@@ -173,7 +173,8 @@ _svmh_invoke_nonvirtual_$1 (_svmt_JNIEnv *env, jobject m4svm_arglist)
     size_t offset =
       env->stack.current_frame->end_offset + frame_info->start_offset;
     _svmt_stack_frame *frame =
-      (_svmt_stack_frame *) (((char *) env->stack.current_frame) + offset);
+      (_svmt_stack_frame *) (void *) (((char *) env->stack.current_frame) +
+				      offset);
 
     frame->previous_offset = offset;
     frame->end_offset = frame_info->end_offset;
@@ -198,7 +199,7 @@ _svmh_invoke_nonvirtual_$1 (_svmt_JNIEnv *env, jobject m4svm_arglist)
     assert (frame->method == &vm->vm_initiated_call_method);
 
     /* pop frame */
-    env->stack.current_frame = (_svmt_stack_frame *)
+    env->stack.current_frame = (_svmt_stack_frame *) (void *)
       (((char *) frame) - frame->previous_offset);
 
     /* rethrow exception */
@@ -213,7 +214,7 @@ _svmh_invoke_nonvirtual_$1 (_svmt_JNIEnv *env, jobject m4svm_arglist)
      * [:
      *     /[::]* set the return value *[::]/
      *     {
-     *       _svmt_stack_value *ptr_ret = (_svmt_stack_value *)
+     *       _svmt_stack_value *ptr_ret = (_svmt_stack_value *) (void *)
      *         (((char *) frame) + frame->end_offset);
      *
      *       m4_ifelse(
@@ -283,7 +284,7 @@ _svmh_invoke_specific_nonvirtual_$1
  * $:][:2, jobject, [:, jobject ret:],
  * :]m4svm_lbkt[:, $:][:2 *ret:]m4svm_rbkt[:)[::]m4_dnl
  * :]:]) */
-static jint
+svm_static jint
 _svmh_invoke_specific_nonvirtual_$1 (_svmt_JNIEnv *env,
 				     _svmt_method_info *method,
 				     jobject m4svm_arglist)
@@ -321,7 +322,7 @@ _svmh_invoke_specific_nonvirtual_$1 (_svmt_JNIEnv *env,
   /* setup internal call frame */
   {
     size_t offset = env->stack.current_frame->end_offset;
-    _svmt_stack_frame *frame = (_svmt_stack_frame *)
+    _svmt_stack_frame *frame = (_svmt_stack_frame *) (void *)
       (((char *) env->stack.current_frame) + offset);
 
     frame->previous_offset = offset;
@@ -339,7 +340,7 @@ _svmh_invoke_specific_nonvirtual_$1 (_svmt_JNIEnv *env,
   /* push parameters */
   {
     _svmt_stack_frame *prev_frame = env->stack.current_frame;
-    _svmt_stack_value *locals = (_svmt_stack_value *)
+    _svmt_stack_value *locals = (_svmt_stack_value *) (void *)
       (((char *) prev_frame) + prev_frame->end_offset);
     jint i = 0;
 
@@ -396,7 +397,8 @@ _svmh_invoke_specific_nonvirtual_$1 (_svmt_JNIEnv *env,
     size_t offset =
       env->stack.current_frame->end_offset + frame_info->start_offset;
     _svmt_stack_frame *frame =
-      (_svmt_stack_frame *) (((char *) env->stack.current_frame) + offset);
+      (_svmt_stack_frame *) (void *) (((char *) env->stack.current_frame) +
+				      offset);
 
     frame->previous_offset = offset;
     frame->end_offset = frame_info->end_offset;
@@ -421,7 +423,7 @@ _svmh_invoke_specific_nonvirtual_$1 (_svmt_JNIEnv *env,
     assert (frame->method == &vm->vm_initiated_call_method);
 
     /* pop frame */
-    env->stack.current_frame = (_svmt_stack_frame *)
+    env->stack.current_frame = (_svmt_stack_frame *) (void *)
       (((char *) frame) - frame->previous_offset);
 
     /* rethrow exception */
@@ -436,7 +438,7 @@ _svmh_invoke_specific_nonvirtual_$1 (_svmt_JNIEnv *env,
      * [:
      *     /[::]* set the return value *[::]/
      *     {
-     *       _svmt_stack_value *ptr_ret = (_svmt_stack_value *)
+     *       _svmt_stack_value *ptr_ret = (_svmt_stack_value *) (void *)
      *         (((char *) frame) + frame->end_offset);
      *
      *       m4_ifelse(
@@ -506,7 +508,7 @@ _svmh_invoke_static_$1
  * $:][:2, jobject, [:, jobject ret:],
  * :]m4svm_lbkt[:, $:][:2 *ret:]m4svm_rbkt[:)[::]m4_dnl
  * :]:]) */
-static jint
+svm_static jint
 _svmh_invoke_static_$1 (_svmt_JNIEnv *m4svm_arglist)
 {
   _svmt_JavaVM *vm = env->vm;
@@ -538,7 +540,7 @@ _svmh_invoke_static_$1 (_svmt_JNIEnv *m4svm_arglist)
   /* setup internal call frame */
   {
     size_t offset = env->stack.current_frame->end_offset;
-    _svmt_stack_frame *frame = (_svmt_stack_frame *)
+    _svmt_stack_frame *frame = (_svmt_stack_frame *) (void *)
       (((char *) env->stack.current_frame) + offset);
 
     frame->previous_offset = offset;
@@ -556,7 +558,7 @@ _svmh_invoke_static_$1 (_svmt_JNIEnv *m4svm_arglist)
   /* push parameters */
   {
     _svmt_stack_frame *prev_frame = env->stack.current_frame;
-    _svmt_stack_value *locals = (_svmt_stack_value *)
+    _svmt_stack_value *locals = (_svmt_stack_value *) (void *)
       (((char *) prev_frame) + prev_frame->end_offset);
     jint i = 0;
 
@@ -612,7 +614,8 @@ _svmh_invoke_static_$1 (_svmt_JNIEnv *m4svm_arglist)
     size_t offset =
       env->stack.current_frame->end_offset + frame_info->start_offset;
     _svmt_stack_frame *frame =
-      (_svmt_stack_frame *) (((char *) env->stack.current_frame) + offset);
+      (_svmt_stack_frame *) (void *) (((char *) env->stack.current_frame) +
+				      offset);
 
     frame->previous_offset = offset;
     frame->end_offset = frame_info->end_offset;
@@ -637,7 +640,7 @@ _svmh_invoke_static_$1 (_svmt_JNIEnv *m4svm_arglist)
     assert (frame->method == &vm->vm_initiated_call_method);
 
     /* pop frame */
-    env->stack.current_frame = (_svmt_stack_frame *)
+    env->stack.current_frame = (_svmt_stack_frame *) (void *)
       (((char *) frame) - frame->previous_offset);
 
     /* rethrow exception */
@@ -652,7 +655,7 @@ _svmh_invoke_static_$1 (_svmt_JNIEnv *m4svm_arglist)
      * [:
      *     /[::]* set the return value *[::]/
      *     {
-     *       _svmt_stack_value *ptr_ret = (_svmt_stack_value *)
+     *       _svmt_stack_value *ptr_ret = (_svmt_stack_value *) (void *)
      *         (((char *) frame) + frame->end_offset);
      *
      *       m4_ifelse(
@@ -722,7 +725,7 @@ _svmh_invoke_specific_static_$1
  * $:][:2, jobject, [:, jobject ret:],
  * :]m4svm_lbkt[:, $:][:2 *ret:]m4svm_rbkt[:)[::]m4_dnl
  * :]:]) */
-static jint
+svm_static jint
 _svmh_invoke_specific_static_$1 (_svmt_JNIEnv *env,
 				 _svmt_method_info *m4svm_arglist)
 {
@@ -757,7 +760,7 @@ _svmh_invoke_specific_static_$1 (_svmt_JNIEnv *env,
   /* setup internal call frame */
   {
     size_t offset = env->stack.current_frame->end_offset;
-    _svmt_stack_frame *frame = (_svmt_stack_frame *)
+    _svmt_stack_frame *frame = (_svmt_stack_frame *) (void *)
       (((char *) env->stack.current_frame) + offset);
 
     frame->previous_offset = offset;
@@ -775,7 +778,7 @@ _svmh_invoke_specific_static_$1 (_svmt_JNIEnv *env,
   /* push parameters */
   {
     _svmt_stack_frame *prev_frame = env->stack.current_frame;
-    _svmt_stack_value *locals = (_svmt_stack_value *)
+    _svmt_stack_value *locals = (_svmt_stack_value *) (void *)
       (((char *) prev_frame) + prev_frame->end_offset);
     jint i = 0;
 
@@ -831,7 +834,8 @@ _svmh_invoke_specific_static_$1 (_svmt_JNIEnv *env,
     size_t offset =
       env->stack.current_frame->end_offset + frame_info->start_offset;
     _svmt_stack_frame *frame =
-      (_svmt_stack_frame *) (((char *) env->stack.current_frame) + offset);
+      (_svmt_stack_frame *) (void *) (((char *) env->stack.current_frame) +
+				      offset);
 
     frame->previous_offset = offset;
     frame->end_offset = frame_info->end_offset;
@@ -856,7 +860,7 @@ _svmh_invoke_specific_static_$1 (_svmt_JNIEnv *env,
     assert (frame->method == &vm->vm_initiated_call_method);
 
     /* pop frame */
-    env->stack.current_frame = (_svmt_stack_frame *)
+    env->stack.current_frame = (_svmt_stack_frame *) (void *)
       (((char *) frame) - frame->previous_offset);
 
     /* rethrow exception */
@@ -871,7 +875,7 @@ _svmh_invoke_specific_static_$1 (_svmt_JNIEnv *env,
      * [:
      *     /[::]* set the return value *[::]/
      *     {
-     *       _svmt_stack_value *ptr_ret = (_svmt_stack_value *)
+     *       _svmt_stack_value *ptr_ret = (_svmt_stack_value *) (void *)
      *         (((char *) frame) + frame->end_offset);
      *
      *       m4_ifelse(
