@@ -879,7 +879,7 @@ _svmf_invoke_native_static (_svmt_JNIEnv *env)
     }
 
   /* going native */
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   {
     _svmt_stack_value result[2];
@@ -889,7 +889,7 @@ _svmf_invoke_native_static (_svmt_JNIEnv *env)
 	      method->data.native_method->code, &result, ptrs);
 
     /* coming back */
-    _svmf_resuming_java (env);
+    _svmm_resuming_java (env);
 
     /* retrieve current frame */
     frame = env->stack.current_frame;
@@ -1360,7 +1360,7 @@ _svmf_invoke_native_nonstatic (_svmt_JNIEnv *env)
 
 
   /* going native */
-  _svmf_stopping_java (env);
+  _svmm_stopping_java (env);
 
   {
     _svmt_stack_value result[2];
@@ -1370,7 +1370,7 @@ _svmf_invoke_native_nonstatic (_svmt_JNIEnv *env)
 	      method->data.native_method->code, &result, ptrs);
 
     /* coming back */
-    _svmf_resuming_java (env);
+    _svmm_resuming_java (env);
 
     /* retrieve current frame */
     frame = env->stack.current_frame;
