@@ -12,9 +12,6 @@ _svmh_new_array_instance
 ----------------------------------------------------------------------
 */
 
-#define _svmm_new_array_instance(env, array_info, size, instance) \
-_svmh_new_array_instance(env, array_info, size, &instance)
-
 svm_static jint
 _svmh_new_array_instance (_svmt_JNIEnv *env, _svmt_array_info *array_info,
 			  jint size, _svmt_array_instance **pinstance)
@@ -434,3 +431,85 @@ _svmf_clone_instance (_svmt_JNIEnv *env, jobject orig, jobject clone)
 
   return _svmf_clone_object_instance (env, orig, clone);
 }
+
+/*
+----------------------------------------------------------------------
+_svmm_multianewarray
+----------------------------------------------------------------------
+*/
+
+svm_static jint
+_svmh_multianewarray (_svmt_JNIEnv *env, _svmt_array_info *array_info,
+		      jint dimensions, _svmt_stack_value counts[],
+		      _svmt_array_instance **pinstance)
+{
+  jint count = counts[0].jint;
+  jarray array;
+
+  if (count < 0)
+    {
+      _svmf_error_NegativeArraySizeException (env);
+      return JNI_ERR;
+    }
+
+  if (_svmm_new_native_local_array (env, array) != JNI_OK)
+    {
+      return JNI_ERR;
+    }
+
+
+  if (_svmm_new_array_instance (env, array_info, count, *array) != JNI_OK)
+    {
+      _svmm_free_native_local_array (env, array);
+      return JNI_ERR;
+    }
+
+  if (count > 0 && dimensions > 1)
+    {
+      jint i;
+
+      for (i = 0; i < count; i++)
+	{
+	  _svmt_array_instance *instance;
+	  _svmt_array_instance **elements;
+
+	  if (_svmm_multianewarray
+	      (env, array_info->array_element, dimensions - 1, counts[1],
+	       instance) != JNI_OK)
+	    {
+	      _svmm_free_native_local_array (env, array);
+	      return JNI_ERR;
+	    }
+
+#if defined (_SABLEVM_BIDIRECTIONAL_OBJECT_LAYOUT)
+
+	  elements = (_svmt_array_instance **) (*array);
+	  elements[(-1) - i] = instance;
+#if defined (_SABLEVM_GC_WRITE_BARRIER)
+	  _svmf_write_barrier
+	    (env, (_svmt_object_instance **) &elements[(-1) - i]);
+#endif /* _SABLEVM_GC_WRITE_BARRIER */
+
+#else
+
+	  elements = (_svmt_array_instance **)
+	    (((char *) *array) +
+	     _svmf_aligned_size_t (sizeof (_svmt_array_instance)));
+	  elements[i] = instance;
+#if defined (_SABLEVM_GC_WRITE_BARRIER)
+	  _svmf_write_barrier (env, (_svmt_object_instance **) &elements[i]);
+#endif /* _SABLEVM_GC_WRITE_BARRIER */
+
+#endif
+	}
+    }
+
+  *pinstance = *array;
+
+#if defined (MAGIC) && !defined (_SABLEVM_INLINED_THREADED_INTERPRETER)
+  assert (*array == NULL || strcmp ((*array)->magic, "SableVM") == 0);
+#endif
+
+  _svmm_free_native_local_array (env, array);
+  return JNI_OK;
+}
