@@ -492,7 +492,7 @@ _svmf_prepare_class_lockword (_svmt_class_info *class)
 
   _svmt_word end =
     (class->data.noninterface.next_offset_no_hashcode - _svmf_aligned_size_t
-     (sizeof (_svmt_object_instance))) / SVM_ALIGNMENT;
+     (sizeof (_svmt_object_instance))) / sizeof (void *);
   _svmt_word offsets = 0;
   const size_t head_size =
     _svmf_aligned_size_t (sizeof (_svmt_object_instance));
@@ -501,9 +501,6 @@ _svmf_prepare_class_lockword (_svmt_class_info *class)
   size_t *ref_field_offsets = class->data.noninterface.ref_field_offsets;
   jboolean overflow = JNI_FALSE;
 
-  /* we're on ia32, so alignment should be the same as ptr size */
-  assert (SVM_ALIGNMENT == sizeof (void *));
-
   if (end > 7)
     {
       overflow = JNI_TRUE;
