@@ -243,9 +243,34 @@ struct _svmt_JNIEnv_struct
 
 #endif				/* _SABLEVM_SIGNALS_FOR_EXCEPTIONS || _SABLEVM_INLINABILITY_TESTING */
 
-  /* status for "stop_the_world" operations */
+  /* fields for "stop_the_world" and "suspend" operations */
   volatile _svmt_word thread_status;
 
+  /* flags used to indicate the reason why a thread status is not
+     RUNNING_JAVA or NOT_RUNNING_JAVA_RESUMING_ALLOWED.  Access to
+     this variable should be protected by the global mutex. */
+  jint status_flags;
+
+  /* condition variable used by this thread to wake up from
+     stop_the_world and suspend operations */
+  pthread_cond_t wakeup_cond;
+
+  struct
+  {
+    /* list of threads that have requested the suspension of this
+       thread.  Protected by global mutex. */
+    _svmt_JNIEnv *suspender_list;
+
+    /* points to the next thread when this thread is in the
+       suspender_list of another thread. */
+    _svmt_JNIEnv *suspender_list_next;
+
+    /* condition variable used by this thread to receive suspension
+       notifications */
+    pthread_cond_t cond;
+  }
+  suspension;
+
   /* fields for dealing with thinlock contention */
   struct
   {
@@ -284,6 +309,24 @@ struct _svmt_JNIEnv_struct
 
 #include "error_bits.h"
 
+#ifndef NDEBUG
+
+  struct
+  {
+    jint last_index;
+    struct
+    {
+      const char *action;
+      const char *file;
+      const char *func;
+      int line;
+      _svmt_word entry;
+      _svmt_word exit;
+    } info[SVM_STOP_RESUME_TRACE_SIZE];
+  } stop_resume;
+
+#endif
+
 };
 
 /*
@@ -303,6 +346,7 @@ struct _svmt_classes_struct
   _svmt_class_info *jlrmethod;
   _svmt_class_info *jlstacktraceelement;
   _svmt_class_info *jlvmclass;
+  _svmt_class_info *niobytebuffervm;
   _svmt_class_info *stringcreator;
   _svmt_class_info *virtualmachine;
 
@@ -349,8 +393,19 @@ struct _svmt_methods_struct
   _svmt_method_info *virtualmachine_createclass;
   _svmt_method_info *virtualmachine_createrootthread;
   _svmt_method_info *virtualmachine_exceptiondescribe;
+  _svmt_method_info *virtualmachine_exceptiondescription;
+  _svmt_method_info *virtualmachine_exceptiontruncateddescription;
   _svmt_method_info *virtualmachine_getsystemcl;
   _svmt_method_info *virtualmachine_runthread;
+  _svmt_method_info *niobytebuffervm_getcapacity;
+
+#if SVM_WORD_BIT_COUNT == 32
+  _svmt_method_info *niobytebuffervm_newbuffer32;
+  _svmt_method_info *niobytebuffervm_getaddress32;
+#elif SVM_WORD_BIT_COUNT == 64
+  _svmt_method_info *niobytebuffervm_newbuffer64;
+  _svmt_method_info *niobytebuffervm_getaddress64;
+#endif
 
 #include "error_init_methods.h"
 
@@ -365,6 +420,9 @@ _svmt_fields
 struct _svmt_fields_struct
 {
   _svmt_field_info *jlclass_vmdata;
+  _svmt_field_info *jlrfield_vmdata;
+  _svmt_field_info *jlrmethod_vmdata;
+  _svmt_field_info *jlrconstructor_vmdata;
   _svmt_field_info *jlstacktraceelement_next;
   _svmt_field_info *jlstacktraceelement_length;
 };
@@ -993,9 +1051,12 @@ struct _svmt_JavaVM_struct
   pthread_mutex_t global_mutex;
 
   /* stop-the-world fields */
-  jint pending_halt_thread_count;
-  pthread_cond_t requesting_thread_cond;
-  pthread_cond_t halted_threads_cond;
+  struct
+  {
+    jint pending_halt_thread_count;
+    pthread_cond_t requesting_thread_cond;
+  }
+  stop_the_world;
 
   /* raw instruction pointer array */
   _svmt_instruction_info *instructions;	/* [SVM_INSTRUCTION_COUNT]; */
@@ -1031,6 +1092,8 @@ struct _svmt_JavaVM_struct
   jboolean verbose_gc;
   jboolean verbose_jni;
 
+  jboolean enforce_structured_locking;
+
 #if !defined(NDEBUG)
 
   jboolean verbose_exceptions;	/* dump stack trace for every thrown exception */
