@@ -18,6 +18,9 @@ memset(&var, 0, sizeof(var))
 #define _svmm_set_flag(value,flag) \
 _svmh_set_flag(&value, flag)
 
+#define _svmm_clear_flag(value,flag) \
+_svmh_clear_flag(&value, flag)
+
 #define _svmm_validate_min_max_increment(min,max,incr) \
 _svmh_validate_min_max_increment (&min, &max, &incr)
 
