@@ -162,6 +162,18 @@ _svmh_set_flag (jint *pvalue, jint flag)
   *pvalue |= flag;
 }
 
+/*
+----------------------------------------------------------------------
+_svmh_clear_flag
+----------------------------------------------------------------------
+*/
+
+inline static void
+_svmh_clear_flag (jint *pvalue, jint flag)
+{
+  *pvalue &= ~flag;
+}
+
 /*
 ----------------------------------------------------------------------
 _svmf_is_interface
