@@ -20,6 +20,7 @@ _svmh_identity_hashcode (_svmt_JNIEnv *env, jobject obj, jint *phashcode)
 {
   _svmt_JavaVM *vm = env->vm;
   jboolean monitor_acquired = JNI_FALSE;
+  _svmt_JNIEnv *owner = NULL;
 
   /* is it an array? */
   if (_svmf_lockword_is_array ((*obj)->lockword))
@@ -39,20 +40,161 @@ retry:
       {
       case SVM_HASH_NONE:
 	{
-	  /* The untold story in the 2 bits hashcode is the hidden
-	     synchronization on first access...  Even though
-	     surprizing, this doesn't seem in contradiction with the
-	     API spec. */
+	  /* The untold story in the 2 bits hashcode within a thin
+	     lock is that it cannot be modified unless a) the current
+	     thread owns the lock, or b) the owning thread is
+	     suspended.
+	   */
 
 	  if (!monitor_acquired)
 	    {
-	      if (_svmf_enter_object_monitor (env, *obj))
+	      jboolean succeeded = JNI_FALSE;	/* init just to keep compiler happy */
+
+	      if (_svmm_enter_object_monitor_non_blocking
+		  (env, instance, succeeded))
 		{
 		  return JNI_ERR;
 		}
 
-	      monitor_acquired = JNI_TRUE;
-	      goto retry;
+	      if (succeeded)
+		{
+		  monitor_acquired = JNI_TRUE;
+		  goto retry;
+		}
+
+	      /* refresh values, in case GC happened in enter_monitor call */
+	      instance = *obj;
+
+	      /* contention: another thread owns the lock.  Suspend it. */
+	      {
+		_svmt_word lockword = instance->lockword;
+
+		if (_svmf_lockword_is_thin (lockword))
+		  {
+		    jint owner_id = _svmf_lockword_get_thread_id (lockword);
+
+		    assert (owner_id != env->thread.id);
+
+		    owner = vm->threads.array[owner_id];
+
+		    /* If the lock has been released, retry. */
+		    if (owner == NULL)
+		      {
+			goto retry;
+		      }
+
+		    _svmm_mutex_lock (vm->global_mutex);
+
+		    assert (env != owner);
+
+		    /* suspend owner thread */
+		    _svmf_suspend_thread (env, owner);
+
+		    _svmm_mutex_unlock ();
+
+		    /* refresh values */
+		    instance = *obj;
+		    lockword = instance->lockword;
+
+		    if (_svmf_lockword_is_thin (lockword))
+		      {
+			owner_id = _svmf_lockword_get_thread_id (lockword);
+		      }
+		    else
+		      {
+			owner_id = 0;	/* so that we retry */
+		      }
+
+		    /* make sure it is still owner */
+		    if (owner != vm->threads.array[owner_id])
+		      {
+			_svmm_mutex_lock (vm->global_mutex);
+
+			/* resume owner thread */
+			_svmf_resume_thread (env, owner);
+
+			_svmm_mutex_unlock ();
+
+			owner = NULL;
+			goto retry;
+		      }
+		  }
+		else
+		  {
+		    /* it is a fat lock */
+
+		    _svmt_word fat_index =
+		      _svmf_lockword_get_fatlock_index (lockword);
+		    _svmt_fat_lock *fat_lock = vm->fat_locks.array[fat_index];
+
+		    _svmm_mutex_lock (fat_lock->mutex);
+
+		    if (fat_lock->recursive_count != 0)
+		      {
+			owner = fat_lock->owner;
+		      }
+
+		    _svmm_mutex_unlock ();
+
+		    /* If the lock has been released, retry. */
+		    if (owner == NULL)
+		      {
+			goto retry;
+		      }
+
+		    _svmm_mutex_lock (vm->global_mutex);
+
+		    assert (env != owner);
+
+		    /* suspend owner thread */
+		    _svmf_suspend_thread (env, owner);
+
+		    _svmm_mutex_unlock ();
+
+		    /* refresh values */
+		    instance = *obj;
+		    lockword = instance->lockword;
+
+		    {
+		      jboolean changed = JNI_FALSE;
+
+		      if (!_svmf_lockword_is_thin (lockword))
+			{
+			  fat_index =
+			    _svmf_lockword_get_fatlock_index (lockword);
+			  fat_lock = vm->fat_locks.array[fat_index];
+
+			  _svmm_mutex_lock (fat_lock->mutex);
+
+			  if (fat_lock->recursive_count == 0
+			      || owner != fat_lock->owner)
+			    {
+			      changed = JNI_TRUE;
+			    }
+
+			  _svmm_mutex_unlock ();
+			}
+		      else
+			{
+			  changed = JNI_TRUE;
+			}
+
+		      /* make sure it is still owner */
+		      if (changed)
+			{
+			  _svmm_mutex_lock (vm->global_mutex);
+
+			  /* resume owner thread */
+			  _svmf_resume_thread (env, owner);
+
+			  _svmm_mutex_unlock ();
+
+			  owner = NULL;
+			  goto retry;
+			}
+		    }
+		  }
+	      }
 	    }
 
 #if defined (_SABLEVM_COPY_GC) || defined (_SABLEVM_GENCOPY_GC)
@@ -92,9 +234,25 @@ retry:
 
 	    if (status != JNI_OK)
 	      {
-		if (_svmf_exit_object_monitor (env, *obj) != JNI_OK)
+		if (monitor_acquired)
 		  {
-		    return JNI_ERR;
+		    assert (owner == NULL);
+
+		    if (_svmf_exit_object_monitor (env, *obj) != JNI_OK)
+		      {
+			return JNI_ERR;
+		      }
+		  }
+		else
+		  {
+		    assert (owner != NULL);
+
+		    _svmm_mutex_lock (vm->global_mutex);
+
+		    /* resume owner thread */
+		    _svmf_resume_thread (env, owner);
+
+		    _svmm_mutex_unlock ();
 		  }
 
 		_svmf_error_OutOfMemoryError (env);
@@ -169,6 +327,15 @@ retry:
 	  return JNI_ERR;
 	}
     }
+  else if (owner != NULL)
+    {
+      _svmm_mutex_lock (vm->global_mutex);
+
+      /* resume owner thread */
+      _svmf_resume_thread (env, owner);
+
+      _svmm_mutex_unlock ();
+    }
 
   return JNI_OK;
 }
@@ -846,6 +1013,68 @@ _svmf_unwrap_class_instance (_svmt_JNIEnv *env, jclass class)
   return (_svmt_type_info *) _svmf_unwrap_pointer (vmdata);
 }
 
+/*
+----------------------------------------------------------------------
+_svmf_unwrap_field_instance
+----------------------------------------------------------------------
+*/
+
+svm_static _svmt_field_info *
+_svmf_unwrap_field_instance (_svmt_JNIEnv *env, jobject obj)
+{
+  _svmt_JavaVM *vm = env->vm;
+  _svmt_array_instance *vmdata;
+
+  vmdata = _svmf_cast_array_instance
+    (_svmf_get_REFERENCE_field (*obj,
+				vm->class_loading.boot_loader.fields.
+				jlrfield_vmdata->data.instance_field.offset));
+
+  return (_svmt_field_info *) _svmf_unwrap_pointer (vmdata);
+}
+
+/*
+----------------------------------------------------------------------
+_svmf_unwrap_method_instance
+----------------------------------------------------------------------
+*/
+
+svm_static _svmt_method_info *
+_svmf_unwrap_method_instance (_svmt_JNIEnv *env, jobject obj)
+{
+  _svmt_JavaVM *vm = env->vm;
+  _svmt_array_instance *vmdata;
+
+  vmdata = _svmf_cast_array_instance
+    (_svmf_get_REFERENCE_field (*obj,
+				vm->class_loading.boot_loader.fields.
+				jlrmethod_vmdata->data.instance_field.
+				offset));
+
+  return (_svmt_method_info *) _svmf_unwrap_pointer (vmdata);
+}
+
+/*
+----------------------------------------------------------------------
+_svmf_unwrap_constructor_instance
+----------------------------------------------------------------------
+*/
+
+svm_static _svmt_method_info *
+_svmf_unwrap_constructor_instance (_svmt_JNIEnv *env, jobject obj)
+{
+  _svmt_JavaVM *vm = env->vm;
+  _svmt_array_instance *vmdata;
+
+  vmdata = _svmf_cast_array_instance
+    (_svmf_get_REFERENCE_field (*obj,
+				vm->class_loading.boot_loader.fields.
+				jlrconstructor_vmdata->data.instance_field.
+				offset));
+
+  return (_svmt_method_info *) _svmf_unwrap_pointer (vmdata);
+}
+
 /*
 ----------------------------------------------------------------------
 _svmf_new_class
@@ -932,91 +1161,6 @@ _svmf_find_method_in_class (_svmt_class_info *class, const char *name,
 }
 */
 
-/*
-----------------------------------------------------------------------
-_svmm_multianewarray
-----------------------------------------------------------------------
-*/
-
-#define _svmm_multianewarray(env, array_info, dimensions, counts, instance) \
-_svmh_multianewarray (env, array_info, dimensions, &counts, &instance)
-
-svm_static jint
-_svmh_multianewarray (_svmt_JNIEnv *env, _svmt_array_info *array_info,
-		      jint dimensions, _svmt_stack_value counts[],
-		      _svmt_array_instance **pinstance)
-{
-  jint count = counts[0].jint;
-  jarray array;
-
-  if (count < 0)
-    {
-      _svmf_error_NegativeArraySizeException (env);
-      return JNI_ERR;
-    }
-
-  if (_svmm_new_native_local_array (env, array) != JNI_OK)
-    {
-      return JNI_ERR;
-    }
-
-
-  if (_svmm_new_array_instance (env, array_info, count, *array) != JNI_OK)
-    {
-      _svmm_free_native_local_array (env, array);
-      return JNI_ERR;
-    }
-
-  if (count > 0 && dimensions > 1)
-    {
-      jint i;
-
-      for (i = 0; i < count; i++)
-	{
-	  _svmt_array_instance *instance;
-	  _svmt_array_instance **elements;
-
-	  if (_svmm_multianewarray
-	      (env, array_info->array_element, dimensions - 1, counts[1],
-	       instance) != JNI_OK)
-	    {
-	      _svmm_free_native_local_array (env, array);
-	      return JNI_ERR;
-	    }
-
-#if defined (_SABLEVM_BIDIRECTIONAL_OBJECT_LAYOUT)
-
-	  elements = (_svmt_array_instance **) (*array);
-	  elements[(-1) - i] = instance;
-#if defined (_SABLEVM_GC_WRITE_BARRIER)
-	  _svmf_write_barrier
-	    (env, (_svmt_object_instance **) &elements[(-1) - i]);
-#endif /* _SABLEVM_GC_WRITE_BARRIER */
-
-#else
-
-	  elements = (_svmt_array_instance **)
-	    (((char *) *array) +
-	     _svmf_aligned_size_t (sizeof (_svmt_array_instance)));
-	  elements[i] = instance;
-#if defined (_SABLEVM_GC_WRITE_BARRIER)
-	  _svmf_write_barrier (env, (_svmt_object_instance **) &elements[i]);
-#endif /* _SABLEVM_GC_WRITE_BARRIER */
-
-#endif
-	}
-    }
-
-  *pinstance = *array;
-
-#if defined (MAGIC) && !defined (_SABLEVM_INLINED_THREADED_INTERPRETER)
-  assert (*array == NULL || strcmp ((*array)->magic, "SableVM") == 0);
-#endif
-
-  _svmm_free_native_local_array (env, array);
-  return JNI_OK;
-}
-
 /*
 ----------------------------------------------------------------------
 _svmf_get_string
