@@ -9,6 +9,12 @@
 #ifndef SVM_SABLEVM_H
 #define SVM_SABLEVM_H
 
+#if defined(__GNUC__)
+#define SVM_CAST_EXTENSION __extension__
+#else
+#define SVM_CAST_EXTENSION
+#endif
+
 /*
   Note: By not defining headers for static non-recursive
   functions, we give the compiler better opportunities
